version 15.1
set more off
clear*

* set working directory
cd "/Users/dan/Google Drive/Chile_Paper/JDE REVISION/THIRD JDE SUBMISSION/REPLICATION FILES (Apr 2018)"

* MSCI WORLD INDEX
import excel "other data/World_monthly_USD.xls", sheet("History Index") cellrange(A7:G380) firstrow clear
keep Date WORLD
rename WORLD msci_world_index
gen month=mofd(Date)
format month %tm
tempfile world
save `world'

* CHILE IGPA DATA (DAILY COLLAPSED TO MONTHLY) (this requires proprietary data on the IGPA index, that can be obtained from the Santiago stock market)
import excel "daily_aggregate_data/daily_IPSA_IGPA_historical.xlsx", sheet("Hoja1") firstrow clear
keep FECHA IGPA IPSA
list FECHA IPSA IGPA if IPSA==0|IGPA==0
* correct some mistakes
replace IPSA=. if IPSA==0
replace IPSA=. if FECHA=="2016-12-23"|FECHA=="2014-12-24"
replace IGPA=. if FECHA=="2016-12-23"|FECHA=="2014-12-24"
replace IGPA=.000222735 if FECHA=="1963-02-18"
replace IGPA=IGPA*1000 if FECHA=="1970-04-09"

gen date= daily(FECHA,"YMD")
gen date_1 = date
format date %td
tsset date

tempfile chile_daily
save `chile_daily'

gen month = mofd(date)
format month %tm
gen year=year(date)
collapse IGPA year, by(month)
drop if IGPA==.
tsset month

tempfile chile_monthly
save `chile_monthly'

* IMF IFS WORLD CPI DATA
insheet using "other data/IFS_07-11-2017 13-25-36-05_panel.csv", comma clear
keep countryname timeperiod consumerpriceindexallitemsindexp equitiesendofperiodindexlocnsh_e equitiesindexfpe_ix grossdomesticproductdeflatorinde interestratesgovernmentsecuritie v19 nationalcurrencypersdrendofperio v25 nationalcurrencypersdrperiodaver nationalcurrencyperusdollarperio
rename consumerpriceindexallitemsindexp ifs_cpi
drop v25 /* not clear what it is: SDR or USD? */
gen frequency = substr(timeperiod,5,1)
keep if frequency=="M"
gen month=monthly(timeperiod, "YM")
format month %tm
keep if countryname=="World"
keep month ifs_cpi
rename ifs_cpi cpi_world
tempfile cpi_world
save `cpi_world'

* OECD CPI DATA (2010=100)
*import delimited "Data/inflation/OECD_m_CPI.csv", delimiter(comma) 
insheet using "other data/OECD_CPI(downloadedJuly2017).csv", comma clear
keep if frequency=="M"
*keep if v6=="Index 2010=100"
keep if subject=="TOT"
keep if measure=="IDX2010"
gen month=monthly(time, "YM")
format month %tm
gen timed = dofm(month) 
gen quarter = qofd(timed)
gen year = year(timed)
format quarter %tq
*translate from ISO country codes to countryname
kountry location, from(iso3c) marker
tab MARKER
tab location if MARKER==0
drop if MARKER==0
rename NAMES_STD countryname
encode countryname, gen(country_id)
* keep cpi variable and save
keep countryname month value quarter year
rename value oecd_cpi
encode countryname, gen(country_id)
xtset country_id month
keep countryname month oecd_cpi

preserve
keep if countryname=="Chile" 
rename oecd_cpi Chile_oecd_cpi
drop countryname
tempfile Chile_oecd_CPI
save `Chile_oecd_CPI'
restore 
preserve
keep if countryname=="Mexico"
rename oecd_cpi Mexico_oecd_cpi
drop countryname
tempfile Mexico_oecd_CPI
save `Mexico_oecd_CPI'
restore
*preserve
*keep if countryname=="Brazil"
*rename oecd_cpi Brazil_oecd_cpi
*drop countryname
*tempfile Brazil_oecd_CPI
*save `Brazil_oecd_CPI'
*restore
keep if countryname=="United States"
rename oecd_cpi us_oecd_cpi
drop countryname
tempfile us_oecd_cpi
save `us_oecd_cpi'

* CHILE MONTHLY INFLATION DATA FROM MALAMAKIS (1970=100)
import excel "other data/Malamakis_data.xlsx", sheet("Sheet1") firstrow clear
drop month
gen Chile_CPI=nominal_IGPA/real_IGPA
sum Chile_CPI if year==1970 & month_num==1
scalar base_value=r(mean)
replace Chile_CPI=Chile_CPI/base_value*100
gen month = ym(year, month_num) 
format month %tm 
tsset month
keep year month Chile_CPI /*nominal_IGPA real_IGPA*/
tempfile Chile_CPI
save `Chile_CPI'

* Brazil stock market data
insheet using "other data/ipeadata[26-07-2017-12-51].csv", clear comma
drop v3
tostring Data, gen(datas) force
gen year = substr(datas, 1, 4)
destring year, replace
gen obs = _n
tsset obs
gen n_month = 12 if year!=f.year & f.year!=.
replace n_month = 5 if year==2017 & f.year==.
forvalues i = 11(-1)1 {
	local j = `i'+1
	replace n_month = `i' if f.n_month==`j'
	}
drop obs
keep data year n_month Índicedeações
gen month = ym(year, n_month)
format month %tm
tsset month

gen IBOVESPA_change=Índicedeações/100
gen IBOVESPA=.
replace IBOVESPA=100 if year==1968 & n_month==2
replace IBOVESPA=l.IBOVESPA*(1+IBOVESPA_change) if IBOVESPA==.
gen check = d.IBOVESPA/l.IBOVESPA
keep month IBOVESPA
tempfile Brazil_IBOVESPA
save `Brazil_IBOVESPA'
 
* Brazil historical CPI data
import excel "other data/ipeadata[27-07-2017-07-57].xls", sheet("series") firstrow clear
gen year = substr(Data, 1, 4)
destring year, replace
gen n_month = substr(Data, 6, 2)
destring n_month, replace
gen month = ym(year, n_month)
format month %tm
tsset month
rename IGPCM Brazil_hist_CPI
keep Brazil_hist_CPI month
tempfile Brazil_hist_cpi
save `Brazil_hist_cpi'
 
*Mexico and USA OECD stock market data (2010=100)
insheet using "other data/OECD_share_prices(downloadedJul2017).csv", comma clear
keep if frequency=="M"
gen month=monthly(time, "YM")
format month %tm
gen timed = dofm(month) 
gen quarter = qofd(timed)
gen year = year(timed)
format quarter %tq
drop if location=="EA19"
*translate from ISO country codes to countryname
kountry location, from(iso3c) marker
tab MARKER
rename NAMES_STD countryname
encode countryname, gen(country_id)
xtset country_id month
keep countryname year quarter month value
rename value oecd_share_prices
replace oecd_share_prices=. if oecd_share_prices==0
keep countryname month year quarter oecd_share_prices
* fix mistake in Brazil data (to be double-checked, perhaps by comparing with IFS and IDB data and daily index)
replace oecd_share_prices=oecd_share_prices*100 if countryname=="Brazil" & month<tm(1993m1) & oecd_share_prices!=.
preserve
keep if countryname=="Mexico"
keep month year oecd_share_prices
rename oecd_share_prices Mexico_oecd_share_prices
tempfile mex_oecd_share_prices
save `mex_oecd_share_prices'
restore 
keep if countryname=="United States"
keep month year oecd_share_prices
rename oecd_share_prices us_oecd_share_prices
tempfile us_oecd_share_prices
save `us_oecd_share_prices'

merge 1:1 month using `mex_oecd_share_prices', nogen
merge 1:1 month using `chile_monthly', nogen
merge 1:1 month using `Chile_oecd_CPI', nogen
merge 1:1 month using `Mexico_oecd_CPI', nogen
*merge 1:1 month using `Brazil_oecd_CPI', nogen
merge 1:1 month using `Chile_CPI', nogen
merge 1:1 month using `us_oecd_cpi', nogen
merge 1:1 month using `world', nogen
merge 1:1 month using `cpi_world', nogen
merge 1:1 month using `Brazil_hist_cpi', nogen
merge 1:1 month using `Brazil_IBOVESPA', nogen

set scheme s1color, permanently

* graphs for the 1970-1974 period
sum msci_world_index if month==tm(1970m1)
scalar world_1970m1 = r(mean)
gen world_nominal_shares=msci_world_index/world_1970m1*100

sum cpi_world if month==tm(1970m1)
scalar world_cpi_1970m1 = r(mean)
gen world_1970cpi = cpi_world/world_cpi_1970m1*100

sum us_oecd_share_prices if month==tm(1970m1)
scalar us_1970m1=r(mean)
gen us_nominal_shares=us_oecd_share_prices/us_1970m1*100

sum us_oecd_cpi if month==tm(1970m1)
scalar us_cpi_1970m1=r(mean)
gen us_1970cpi=us_oecd_cpi/us_cpi_1970m1*100

sum Mexico_oecd_share_prices if month==tm(1970m1)
scalar mex_1970m1=r(mean)
gen mexico_nominal_shares=Mexico_oecd_share_prices/mex_1970m1*100

sum Mexico_oecd_cpi if month==tm(1970m1)
scalar mex_cpi_m1_1970=r(mean)
gen mexico_1970cpi = Mexico_oecd_cpi/mex_cpi_m1_1970*100

sum IBOVESPA if month==tm(1970m1)
scalar bra_1970m1=r(mean)
gen brazil_nominal_shares=IBOVESPA/bra_1970m1*100

sum Brazil_hist_CPI if month==tm(1970m1)
scalar bra_cpi_1970m1 = r(mean)
gen bra_1970cpi=Brazil_hist_CPI/bra_cpi_1970m1*100

sum IGPA if month==tm(1970m1)
scalar ch_1970m1=r(mean)
gen chile_nominal_shares=IGPA/ch_1970m1*100

sum Chile_CPI if month==tm(1970m1)
scalar ch_cpi_1970m1=r(mean)
gen chile_1970cpi = Chile_CPI/ch_cpi_1970m1*100

gen brazil_real_1970_shares=brazil_nominal_shares/bra_1970cpi*100
gen mexico_real_1970_shares=mexico_nominal_shares/mexico_1970cpi*100
gen chile_real_1970_shares=chile_nominal_shares/chile_1970cpi*100
gen us_real_1970_shares=us_nominal_shares/us_1970cpi*100
gen world_real_1970_shares=world_nominal_shares/world_1970cpi*100
label variable mexico_real_1970_shares "Mexico"
label variable chile_real_1970_shares "Chile"
label variable us_real_1970_shares "US"
label variable world_real_1970_shares "World"
label variable brazil_real_1970_shares "Brazil"

gen cosa=month
sum cosa if month==tm(1970m8)
local allende_month=r(mean)
sum cosa if month==tm(1973m8)
local coup_month=r(mean)

*twoway connected us_real_1970_shares mexico_real_1970_shares chile_real_1970_shares world_real_1970_shares brazil_real_1970_shares month if month>=tm(1970m1) & month<=tm(1973m12), name(prova1_real) xline(`allende_month' `coup_month', lstyle( color(cranberry)) lpattern(dash) ) recast(connected) lpattern(shortdash longdash solid solid solid) lcolor(black black black black gs6) msymbol(none Dh O none Th) mcolor(black black black black gs6) mlcolor(black black black black gs6)

twoway connected us_real_1970_shares mexico_real_1970_shares chile_real_1970_shares world_real_1970_shares brazil_real_1970_shares month if month>=tm(1970m1) & month<=tm(1970m12), name(figure_7a) xline(`allende_month', lstyle( color(cranberry)) lpattern(dash) ) lpattern(shortdash longdash solid solid solid) lcolor(black black black black gs6) msymbol(none Dh O none Th) mcolor(black black black black gs6) mlcolor(black black black black gs6) ttext(130 1970m9 "1970 election") xtitle("") tlabel(1970m1(2)1970m12) ttick(1970m1(1)1970m12) ylabel(60(20)140) ytick(60(10)140)
graph export "Figures/Figure_7a.pdf", name(figure_7a) replace

sum world_real_1970_shares if month==tm(1973m1)
scalar world_real_1973m1=r(mean)
gen world_real_1973_shares=world_real_1970_shares/world_real_1973m1*100

sum us_real_1970_shares if month==tm(1973m1)
scalar us_real_1973m1=r(mean)
gen us_real_1973_shares=us_real_1970_shares/us_real_1973m1*100

sum mexico_real_1970_shares if month==tm(1973m1)
scalar mex_real_1973m1=r(mean)
gen mexico_real_1973_shares=mexico_real_1970_shares/mex_real_1973m1*100

sum brazil_real_1970_shares if month==tm(1973m1)
scalar bra_real_1973m1=r(mean)
gen brazil_real_1973_shares=brazil_real_1970_shares/bra_real_1973m1*100

sum chile_real_1970_shares if month==tm(1973m1)
scalar chile_real_1973m1=r(mean)
gen chile_real_1973_shares=chile_real_1970_shares/chile_real_1973m1*100

label variable mexico_real_1973_shares "Mexico"
label variable chile_real_1973_shares "Chile"
label variable us_real_1973_shares "US"
label variable world_real_1973_shares "World"
label variable brazil_real_1973_shares "Brazil"

twoway connected us_real_1973_shares mexico_real_1973_shares chile_real_1973_shares world_real_1973_shares brazil_real_1973_shares month if month>=tm(1973m1) & month<=tm(1973m12), name(figure_7b) xline(`coup_month', lstyle( color(cranberry)) lpattern(dash) ) lpattern(shortdash longdash solid solid solid) lcolor(black black black black gs6) msymbol(none Dh O none Th) mcolor(black black black black gs6) mlcolor(black black black black gs6) ttext(450 1973m7 "1973 coup") xtitle("") tlabel(1973m1(2)1973m12) ttick(1973m1(1)1973m12) ylabel(100(100)400) ytick(100(100)400)
graph export "Figures/Figure_7b.pdf", name(figure_7b) replace
