clear*
set more off
version 15.1

* set working directory
cd "/Users/dan/Google Drive/Chile_Paper/JDE REVISION/THIRD JDE SUBMISSION/REPLICATION FILES (Apr 2018)"

* create daily aggregate dataset (NOTE: this includes proprietary data on the IGPA index, which can be purchased from the Santiago Stock Market)
do create_daily_dataset.do

* set time-window
local w_post 20
local estimation_window 250

* create dummies for different time windows after the two events
forvalues i = 1/`w_post' {
	gen allende_dummy_`i'=0
	replace allende_dummy_`i'=1 if (tdays_to_allende>=1 & tdays_to_allende_election<=`i')
	
	gen coup_dummy_`i'=0
	replace coup_dummy_`i'=1 if (tdays_to_coup>=1 & tdays_to_coup<=`i')
}

* check correlations between indices in the event window
corr igpa_change ibn_change sp500_change if tdays_to_allende>=-`estimation_window' & tdays_to_allende<0

* define the regressors in the 'normal returns' equation, using the index which is most correlated (SP500) in the global market factor-augmented model
local ar l.igpa_change
local gmf sp500_change
local both l.igpa_change sp500_change

** EVENT STUDY TABLE

* 1970 Election 
foreach model in " " "`ar'" "`gmf'" "`both'" {
	foreach i in 1 5 10 15 20 {
		reg igpa_change `model' allende_dummy_`i' if (tdays_to_allende>=-`estimation_window' & tdays_to_allende<=`i'), robust
		scalar election_car_`i' =  _b[allende_dummy_`i']*`i'
		scalar se_election_car_`i' =  _se[allende_dummy_`i']*`i'
	
		dis as text "1970 Election. Controls:`model'; k= "`i' " ; CAR = " election_car_`i' "; SE(CAR) = " se_election_car_`i'
	
	}
}

* 1973 Coup
foreach model in " " "`ar'" "`gmf'" "`both'" {
	foreach i in 1 5 10 15 20 {
		reg igpa_change `model' coup_dummy_`i' if (tdays_to_coup>=-`estimation_window' & tdays_to_coup<=`i'), robust
		scalar coup_car_`i' =  _b[coup_dummy_`i']*`i'
		scalar se_coup_car_`i' =  _se[coup_dummy_`i']*`i'

		dis as text "1973 Coup. Controls:`model'; k= "`i' " ; CAR = " coup_car_`i' "; SE(CAR) = " se_coup_car_`i'
	
	}
}

* for performing the robustness test using the argentina index, substitute ibn_change for sp500_change at lines 29 and 30
