clear*
set more off
version 15.1

set matsize 600

* set working directory
cd "/Users/dan/Google Drive/Chile_Paper/JDE REVISION/THIRD JDE SUBMISSION/REPLICATION FILES (Apr 2018)"

* create daily aggregate dataset (NOTE: this includes proprietary data on the IGPA index, which can be purchased from the Santiago Stock Market)
do create_daily_dataset.do

* set time-window
local w_post 20
local estimation_window 250

* define the regressors in the 'normal returns' equation as in the event-study regression
local ar l.igpa_change
local gmf sp500_change
local both l.igpa_change sp500_change

* set time-window
local w_post 20
local estimation_window 250
	
************ CRITICAL VALUES FOR CARS AFTER THE ALLENDE-SHOCK 
* set range of dates for the randomization test	
sum n if date==td(02jan1968)
local start_date = r(mean)
sum n if date==td(30dec1969)
local end_date = r(mean)

dis as text "start n=" `start_date'
dis as text "end n=" `end_date'
count if n>=`start_date' & n<=`end_date'

* estimate CARs using each of the dates in the range as a 'fake' event date
forvalues p_date = `start_date'/`end_date' {

	gen placebo_election = 0
	replace placebo_election = 1 if n==`p_date'

	* gen variable indicating distance in trading days to the 'placebo event'
	gen tdays_to_placebo = n-`p_date'+1 if n>=`p_date'
	replace tdays_to_placebo = n-`p_date' if n<`p_date'

	* create dummies for different time windows after the placebo event
	forvalues i = 1/`w_post' {
		gen placebo_dummy_`i'=0
		replace placebo_dummy_`i'=1 if (tdays_to_placebo>=1 & tdays_to_placebo<=`i')
		}
		
	* estimate placebo CARs with 'constant mean return' model
	foreach i in 1 5 10 15 20 {
		qui reg igpa_change placebo_dummy_`i' if (tdays_to_placebo>=-`estimation_window' & tdays_to_placebo<=`i'), robust
		scalar car_`p_date'_`i' =  _b[placebo_dummy_`i']*`i'	
		}
		
	if `p_date'== `start_date' {
		mat cars_cmr = ( car_`p_date'_1, car_`p_date'_5, car_`p_date'_10, car_`p_date'_15,  car_`p_date'_20)
		}
			
	else {
		mat cars_cmr = (cars_cmr \ car_`p_date'_1, car_`p_date'_5, car_`p_date'_10, car_`p_date'_15,  car_`p_date'_20 )
		}

	* estimate placebo CARs with 'autocorrelation-augmented' model
	foreach i in 1 5 10 15 20 {
		qui reg igpa_change `ar' placebo_dummy_`i' if (tdays_to_placebo>=-`estimation_window' & tdays_to_placebo<=`i'), robust
		scalar car_`p_date'_`i' =  _b[placebo_dummy_`i']*`i'	
		}
		
	if `p_date'== `start_date' {
		mat cars_ar = ( car_`p_date'_1, car_`p_date'_5, car_`p_date'_10, car_`p_date'_15,  car_`p_date'_20)
		}
			
	else {
		mat cars_ar = (cars_ar \ car_`p_date'_1, car_`p_date'_5, car_`p_date'_10, car_`p_date'_15,  car_`p_date'_20 )
		}		
	
	* estimate placebo CARs with 'global market factor-augmented' model
	foreach i in 1 5 10 15 20 {
		qui reg igpa_change `gmf' placebo_dummy_`i' if (tdays_to_placebo>=-`estimation_window' & tdays_to_placebo<=`i'), robust
		scalar car_`p_date'_`i' =  _b[placebo_dummy_`i']*`i'	
		}
		
	if `p_date'== `start_date' {
		mat cars_gm = ( car_`p_date'_1, car_`p_date'_5, car_`p_date'_10, car_`p_date'_15,  car_`p_date'_20)
		}
			
	else {
		mat cars_gm = (cars_gm \ car_`p_date'_1, car_`p_date'_5, car_`p_date'_10, car_`p_date'_15,  car_`p_date'_20 )
		}		
	
	* estimate placebo CARs with 'autocorrelation + global market factor-augmented' model
	foreach i in 1 5 10 15 20 {
		qui reg igpa_change `both' placebo_dummy_`i' if (tdays_to_placebo>=-`estimation_window' & tdays_to_placebo<=`i'), robust
		scalar car_`p_date'_`i' =  _b[placebo_dummy_`i']*`i'	
		}
		
	if `p_date'== `start_date' {
		mat cars_argm = ( car_`p_date'_1, car_`p_date'_5, car_`p_date'_10, car_`p_date'_15,  car_`p_date'_20)
		}
			
	else {
		mat cars_argm = (cars_argm \ car_`p_date'_1, car_`p_date'_5, car_`p_date'_10, car_`p_date'_15,  car_`p_date'_20 )
		}
		
	drop placebo_dummy_* tdays_to_placebo placebo_election
		
	}
	
	* GET CRITICAL VALUES FOR 'CONSTANT MEAN RETURN MODEL'
	preserve
	drop _all
	svmat cars_cmr
	
	rename cars_cmr5 cars_cmr20
	rename cars_cmr4 cars_cmr15
	rename cars_cmr3 cars_cmr10
	rename cars_cmr2 cars_cmr5
	
	foreach i in 1 5 10 15 20 {
		gen abs_cars`i' = abs(cars_cmr`i')	
		centile abs_cars`i', centile(95 99)
		
		scalar cutoff_95_`i' = r(c_1)
		scalar cutoff_99_`i' = r(c_2)
		
		}
		
	dis as text "95% Critical Values for CARs after the 1970 election in the constant mean return model: " cutoff_95_1 " (with k=1) " cutoff_95_5 " (with k=5) " cutoff_95_10 " (with k=10) " cutoff_95_15 " (with k=15) " cutoff_95_20 " (with k=20) " 
	dis as text "99% Critical Values for CARs after the 1970 election in the constant mean return model: " cutoff_99_1 " (with k=1) " cutoff_99_5 " (with k=5) " cutoff_99_10 " (with k=10) " cutoff_99_15 " (with k=15) " cutoff_99_20 " (with k=20) " 
	
	restore
	
	* GET CRITICAL VALUES FOR 'autocorrelation-augmented' MODEL
	preserve
	drop _all
	svmat cars_ar
	
	rename cars_ar5 cars_ar20
	rename cars_ar4 cars_ar15
	rename cars_ar3 cars_ar10
	rename cars_ar2 cars_ar5
	
	foreach i in 1 5 10 15 20 {
		gen abs_cars`i' = abs(cars_ar`i')	
		centile abs_cars`i', centile(95 99)
		
		scalar cutoff_95_`i' = r(c_1)
		scalar cutoff_99_`i' = r(c_2)
		
		}
		
	dis as text "95% Critical Values for CARs after the 1970 election in the 'autocorrelation-augmented' model: " cutoff_95_1 " (with k=1) " cutoff_95_5 " (with k=5) " cutoff_95_10 " (with k=10) " cutoff_95_15 " (with k=15) " cutoff_95_20 " (with k=20) " 
	dis as text "99% Critical Values for CARs after the 1970 election in the 'autocorrelation-augmented' model: " cutoff_99_1 " (with k=1) " cutoff_99_5 " (with k=5) " cutoff_99_10 " (with k=10) " cutoff_99_15 " (with k=15) " cutoff_99_20 " (with k=20) " 
	
	restore	

	* GET CRITICAL VALUES FOR 'global market factor-augmented' MODEL
	preserve
	drop _all
	svmat cars_gm
	
	rename cars_gm5 cars_gm20
	rename cars_gm4 cars_gm15
	rename cars_gm3 cars_gm10
	rename cars_gm2 cars_gm5
	
	foreach i in 1 5 10 15 20 {
		gen abs_cars`i' = abs(cars_gm`i')	
		centile abs_cars`i', centile(95 99)
		
		scalar cutoff_95_`i' = r(c_1)
		scalar cutoff_99_`i' = r(c_2)
		
		}
		
	dis as text "95% Critical Values for CARs after the 1970 election in the 'global market factor-augmented' model: " cutoff_95_1 " (with k=1) " cutoff_95_5 " (with k=5) " cutoff_95_10 " (with k=10) " cutoff_95_15 " (with k=15) " cutoff_95_20 " (with k=20) " 
	dis as text "99% Critical Values for CARs after the 1970 election in the 'global market factor-augmented' model: " cutoff_99_1 " (with k=1) " cutoff_99_5 " (with k=5) " cutoff_99_10 " (with k=10) " cutoff_99_15 " (with k=15) " cutoff_99_20 " (with k=20) " 
	
	restore		
	
	* GET CRITICAL VALUES FOR 'autocorrelation + global market factor-augmented' MODEL
	preserve
	drop _all
	svmat cars_argm
	
	rename cars_argm5 cars_argm20
	rename cars_argm4 cars_argm15
	rename cars_argm3 cars_argm10
	rename cars_argm2 cars_argm5
	
	foreach i in 1 5 10 15 20 {
		gen abs_cars`i' = abs(cars_argm`i')	

		centile abs_cars`i', centile(95 99)
		
		scalar cutoff_95_`i' = r(c_1)
		scalar cutoff_99_`i' = r(c_2)
		
		}
		
	dis as text "95% Critical Values for CARs after the 1970 election in the 'autocorrelation + global market factor-augmented' model: " cutoff_95_1 " (with k=1) " cutoff_95_5 " (with k=5) " cutoff_95_10 " (with k=10) " cutoff_95_15 " (with k=15) " cutoff_95_20 " (with k=20) " 
	dis as text "99% Critical Values for CARs after the 1970 election in the 'autocorrelation + global market factor-augmented' model: " cutoff_99_1 " (with k=1) " cutoff_99_5 " (with k=5) " cutoff_99_10 " (with k=10) " cutoff_99_15 " (with k=15) " cutoff_99_20 " (with k=20) " 

	restore	
	

************ CRITICAL VALUES FOR CARS AFTER THE 1973 MILITARY COUP
* set range of dates for the randomization test	
sum n if date==td(04dec1970)
local start_date = r(mean)
sum n if date==td(29dec1972)
local end_date = r(mean)

dis as text "start n=" `start_date'
dis as text "end n=" `end_date'
count if n>=`start_date' & n<=`end_date'

* estimate CARs using each of the dates in the range as a 'fake' event date
forvalues p_date = `start_date'/`end_date' {

	gen placebo_coup = 0
	replace placebo_coup = 1 if n==`p_date'

	* gen variable indicating distance in trading days to the 'placebo event'
	gen tdays_to_placebo = n-`p_date'+1 if n>=`p_date'
	replace tdays_to_placebo = n-`p_date' if n<`p_date'

	* create dummies for different time windows after the placebo event
	forvalues i = 1/`w_post' {
		gen placebo_dummy_`i'=0
		replace placebo_dummy_`i'=1 if (tdays_to_placebo>=1 & tdays_to_placebo<=`i')
		}
		
	* estimate placebo CARs with 'constant mean return' model
	foreach i in 1 5 10 15 20 {
		qui reg igpa_change placebo_dummy_`i' if (tdays_to_placebo>=-`estimation_window' & tdays_to_placebo<=`i'), robust
		scalar car_`p_date'_`i' =  _b[placebo_dummy_`i']*`i'	
		}
		
	if `p_date'== `start_date' {
		mat coup_cars_cmr = ( car_`p_date'_1, car_`p_date'_5, car_`p_date'_10, car_`p_date'_15,  car_`p_date'_20)
		}
			
	else {
		mat coup_cars_cmr = (coup_cars_cmr \ car_`p_date'_1, car_`p_date'_5, car_`p_date'_10, car_`p_date'_15,  car_`p_date'_20 )
		}

	* estimate placebo CARs with 'autocorrelation-augmented' model
	foreach i in 1 5 10 15 20 {
		qui reg igpa_change `ar' placebo_dummy_`i' if (tdays_to_placebo>=-`estimation_window' & tdays_to_placebo<=`i'), robust
		scalar car_`p_date'_`i' =  _b[placebo_dummy_`i']*`i'	
		}
		
	if `p_date'== `start_date' {
		mat coup_cars_ar = ( car_`p_date'_1, car_`p_date'_5, car_`p_date'_10, car_`p_date'_15,  car_`p_date'_20)
		}
			
	else {
		mat coup_cars_ar = (coup_cars_ar \ car_`p_date'_1, car_`p_date'_5, car_`p_date'_10, car_`p_date'_15,  car_`p_date'_20 )
		}		
	
	* estimate placebo CARs with 'global market factor-augmented' model
	foreach i in 1 5 10 15 20 {
		qui reg igpa_change `gmf' placebo_dummy_`i' if (tdays_to_placebo>=-`estimation_window' & tdays_to_placebo<=`i'), robust
		scalar car_`p_date'_`i' =  _b[placebo_dummy_`i']*`i'	
		}
		
	if `p_date'== `start_date' {
		mat coup_cars_gm = ( car_`p_date'_1, car_`p_date'_5, car_`p_date'_10, car_`p_date'_15,  car_`p_date'_20)
		}
			
	else {
		mat coup_cars_gm = (coup_cars_gm \ car_`p_date'_1, car_`p_date'_5, car_`p_date'_10, car_`p_date'_15,  car_`p_date'_20 )
		}		
	
	* estimate placebo CARs with 'autocorrelation + global market factor-augmented' model
	foreach i in 1 5 10 15 20 {
		qui reg igpa_change `both' placebo_dummy_`i' if (tdays_to_placebo>=-`estimation_window' & tdays_to_placebo<=`i'), robust
		scalar car_`p_date'_`i' =  _b[placebo_dummy_`i']*`i'	
		}
		
	if `p_date'== `start_date' {
		mat coup_cars_argm = ( car_`p_date'_1, car_`p_date'_5, car_`p_date'_10, car_`p_date'_15,  car_`p_date'_20)
		}
			
	else {
		mat coup_cars_argm = (coup_cars_argm \ car_`p_date'_1, car_`p_date'_5, car_`p_date'_10, car_`p_date'_15,  car_`p_date'_20 )
		}
		
	drop placebo_dummy_* tdays_to_placebo placebo_coup
		
	}
	
	* GET CRITICAL VALUES FOR 'CONSTANT MEAN RETURN MODEL'
	preserve
	drop _all
	svmat coup_cars_cmr
	
	rename coup_cars_cmr5 cars_cmr20
	rename coup_cars_cmr4 cars_cmr15
	rename coup_cars_cmr3 cars_cmr10
	rename coup_cars_cmr2 cars_cmr5
	rename coup_cars_cmr1 cars_cmr1
	
	foreach i in 1 5 10 15 20 {
		gen abs_cars`i' = abs(cars_cmr`i')	
		centile abs_cars`i', centile(95 99)
		
		scalar cutoff_95_`i' = r(c_1)
		scalar cutoff_99_`i' = r(c_2)
		
		}
		
	dis as text "95% Critical Values for CARs after the 1973 coup in the constant mean return model: " cutoff_95_1 " (with k=1) " cutoff_95_5 " (with k=5) " cutoff_95_10 " (with k=10) " cutoff_95_15 " (with k=15) " cutoff_95_20 " (with k=20) " 
	dis as text "99% Critical Values for CARs after the 1973 coup in the constant mean return model: " cutoff_99_1 " (with k=1) " cutoff_99_5 " (with k=5) " cutoff_99_10 " (with k=10) " cutoff_99_15 " (with k=15) " cutoff_99_20 " (with k=20) " 
	
	restore
	
	* GET CRITICAL VALUES FOR 'autocorrelation-augmented' MODEL
	preserve
	drop _all
	svmat coup_cars_ar
	
	rename coup_cars_ar5 cars_ar20
	rename coup_cars_ar4 cars_ar15
	rename coup_cars_ar3 cars_ar10
	rename coup_cars_ar2 cars_ar5
	rename coup_cars_ar1 cars_ar1
	
	foreach i in 1 5 10 15 20 {
		gen abs_cars`i' = abs(cars_ar`i')	
		centile abs_cars`i', centile(95 99)
		
		scalar cutoff_95_`i' = r(c_1)
		scalar cutoff_99_`i' = r(c_2)
		
		}
		
	dis as text "95% Critical Values for CARs after the 1973 coup in the 'autocorrelation-augmented' model: " cutoff_95_1 " (with k=1) " cutoff_95_5 " (with k=5) " cutoff_95_10 " (with k=10) " cutoff_95_15 " (with k=15) " cutoff_95_20 " (with k=20) " 
	dis as text "99% Critical Values for CARs after the 1973 coup in the 'autocorrelation-augmented' model: " cutoff_99_1 " (with k=1) " cutoff_99_5 " (with k=5) " cutoff_99_10 " (with k=10) " cutoff_99_15 " (with k=15) " cutoff_99_20 " (with k=20) " 
	
	restore	

	* GET CRITICAL VALUES FOR 'global market factor-augmented' MODEL
	preserve
	drop _all
	svmat coup_cars_gm
	
	rename coup_cars_gm5 cars_gm20
	rename coup_cars_gm4 cars_gm15
	rename coup_cars_gm3 cars_gm10
	rename coup_cars_gm2 cars_gm5
	rename coup_cars_gm1 cars_gm1
	
	foreach i in 1 5 10 15 20 {
		gen abs_cars`i' = abs(cars_gm`i')	
		centile abs_cars`i', centile(95 99)
		
		scalar cutoff_95_`i' = r(c_1)
		scalar cutoff_99_`i' = r(c_2)
		
		}
		
	dis as text "95% Critical Values for CARs after the 1973 coup in the 'global market factor-augmented' model: " cutoff_95_1 " (with k=1) " cutoff_95_5 " (with k=5) " cutoff_95_10 " (with k=10) " cutoff_95_15 " (with k=15) " cutoff_95_20 " (with k=20) " 
	dis as text "99% Critical Values for CARs after the 1973 coup in the 'global market factor-augmented' model: " cutoff_99_1 " (with k=1) " cutoff_99_5 " (with k=5) " cutoff_99_10 " (with k=10) " cutoff_99_15 " (with k=15) " cutoff_99_20 " (with k=20) " 
	
	restore		
	
	* GET CRITICAL VALUES FOR 'autocorrelation + global market factor-augmented' MODEL
	preserve
	drop _all
	svmat coup_cars_argm
	
	rename coup_cars_argm5 cars_argm20
	rename coup_cars_argm4 cars_argm15
	rename coup_cars_argm3 cars_argm10
	rename coup_cars_argm2 cars_argm5
	rename coup_cars_argm1 cars_argm1
	
	foreach i in 1 5 10 15 20 {
		gen abs_cars`i' = abs(cars_argm`i')	

		centile abs_cars`i', centile(95 99)
		
		scalar cutoff_95_`i' = r(c_1)
		scalar cutoff_99_`i' = r(c_2)
		
		}
		
	dis as text "95% Critical Values for CARs after the 1973 coup in the 'autocorrelation + global market factor-augmented' model: " cutoff_95_1 " (with k=1) " cutoff_95_5 " (with k=5) " cutoff_95_10 " (with k=10) " cutoff_95_15 " (with k=15) " cutoff_95_20 " (with k=20) " 
	dis as text "99% Critical Values for CARs after the 1973 coup in the 'autocorrelation + global market factor-augmented' model: " cutoff_99_1 " (with k=1) " cutoff_99_5 " (with k=5) " cutoff_99_10 " (with k=10) " cutoff_99_15 " (with k=15) " cutoff_99_20 " (with k=20) " 

	restore	
