version 15.1
clear*
set more off

* set working directory
cd "/Users/dan/Google Drive/Chile_Paper/JDE REVISION/THIRD JDE SUBMISSION/REPLICATION FILES (Apr 2018)"

* IMPORT MACRO DATA
* import Penn World Tables National Accounts data
use "macro data/PWT_na_data.dta", clear
keep if countrycode=="CHL"
keep year v_gdp q_gdp
rename q_gdp pwt_RGDP
rename v_gdp pwt_NGDP
tempfile pwt_data
save `pwt_data'


* import Malamakis historical GDP series
import excel "macro data/Chile_historical_GDP_Malamakis.xlsx", sheet("Sheet2") firstrow clear
rename NGDP Malamakis_NGDP
rename RGDP Malamakis_RGDP
destring, replace
rename A year
merge 1:1 year using `pwt_data'
tsset year

foreach source in Malamakis pwt {
	gen `source'_real_growth=(d.`source'_RGDP/l.`source'_RGDP)*100
	gen `source'_nominal_growth=(d.`source'_NGDP/l.`source'_NGDP)*100
	gen `source'_deflator=`source'_NGDP/`source'_RGDP
	gen `source'_inflation=d.`source'_deflator/l.`source'_deflator*100
	}
	
corr Malamakis_real_growth pwt_real_growth
corr Malamakis_nominal_growth pwt_nominal_growth
corr Malamakis_inflation pwt_inflation

gen RGDP_growth=pwt_real_growth
replace RGDP_growth = Malamakis_real_growth if RGDP_growth==.
gen NGDP_growth=pwt_nominal_growth
replace NGDP_growth=Malamakis_nominal_growth if NGDP_growth==.

gen GDP_deflator=pwt_deflator
* backward interpolation
forvalues i=1/15 {
	replace GDP_deflator=f.GDP_deflator/(1+f.Malamakis_inflation/100) if GDP_deflator==.
	}

keep year RGDP_growth NGDP_growth GDP_deflator 
tempfile macrodata
save `macrodata'

* IMPORT GFD SECTORAL INDICES
* import yearly IGPA data
import excel "GFD indices/Santiago SE IGPA inflation-adjusted (annual).xlsx", sheet("Price Data") firstrow clear
gen Date2 = subinstr(Date, "/", "-", .)
gen date = date(Date2, "MDY")
format date %td
g year=year(date)
gen index="igpa"
keep index year Close
rename Close Real_Close
tempfile overall_igpa
save `overall_igpa'

*agriculture fishing and livestock
import excel "GFD indices/Santiago SE Agriculture Fishing Livestock (annual).xlsx", sheet("Price Data") firstrow clear
gen Date2 = subinstr(Date, "/", "-", .)
gen date = date(Date2, "MDY")
format date %td
g year=year(date)
gen index="agriculture"
keep index year Close Real_Close
tempfile agriculture
save `agriculture'

* textiles
import excel "GFD indices/Santiago SE textiles (annual).xlsx", sheet("Price Data") firstrow clear
gen Date2 = subinstr(Date, "/", "-", .)
gen date = date(Date2, "MDY")
format date %td
g year=year(date)
gen index="textiles"
keep index year Close Real_Close
tempfile textiles
save `textiles'

* Metallurgy
import excel "GFD indices/Santiago SE Metallurgy (Annual).xlsx", sheet("Price Data") firstrow clear
gen Date2 = subinstr(Date, "/", "-", .)
gen date = date(Date2, "MDY")
format date %td
g year=year(date)
gen index="metallurgy"
keep index year Close Real_Close
tempfile metallurgy
save `metallurgy'

* Public Utilities 
import excel "GFD indices/Santiago SE public utilities and services (annual).xlsx", sheet("Price Data") firstrow clear
gen Date2 = subinstr(Date, "/", "-", .)
gen date = date(Date2, "MDY")
format date %td
g year=year(date)
gen index="public_utilities"
keep index year Close Real_Close
tempfile public_utilities
save `public_utilities'

* Insurance
import excel "GFD indices/Santiago SE Insurance (annual).xlsx", sheet("Price Data") firstrow clear
gen Date2 = subinstr(Date, "/", "-", .)
gen date = date(Date2, "MDY")
format date %td
g year=year(date)
gen index="insurance"
keep index year Close Real_Close
tempfile insurance
save `insurance'

* Banking
import excel "GFD indices/Santiago SE Banks and Finance (annual).xlsx", sheet("Price Data") firstrow clear
gen Date2 = subinstr(Date, "/", "-", .)
gen date = date(Date2, "MDY")
format date %td
g year=year(date)
gen index="banking"
keep index year Close Real_Close
tempfile banking
save `banking'

* Mining
import excel "GFD indices/Santiago SE Minerals and Mining (annual).xlsx", sheet("Price Data") firstrow clear
gen Date2 = subinstr(Date, "/", "-", .)
gen date = date(Date2, "MDY")
format date %td
g year=year(date)
gen index="mining"
keep index year Close Real_Close
tempfile mining
save `mining'

* Industrials 
import excel "GFD indices/Santiago SE Industrials (annual).xlsx", sheet("Price Data") firstrow clear
gen Date2 = subinstr(Date, "/", "-", .)
gen date = date(Date2, "MDY")
format date %td
g year=year(date)
gen index="industrials"
keep index year Close
tempfile industrials
save `industrials'

* Shipping
import excel "GFD indices/Santiago SE shipping (annual).xlsx", sheet("Price Data") firstrow clear
gen Date2 = subinstr(Date, "/", "-", .)
gen date = date(Date2, "MDY")
format date %td
g year=year(date)
gen index="shipping"
keep index year Close
tempfile shipping
save `shipping'

* merge indexes
clear*
use `agriculture'
foreach sector in textiles metallurgy public_utilities insurance banking mining industrials shipping overall_igpa {
	append using ``sector''
}
encode index, gen(index_id)
xtset index_id year
gen return=d.Close/l.Close*100

* merge indexes with macro data
merge m:1 year using `macrodata'
keep if year>=1940 & year<=1968
xtset index_id year

gen real_close=Close/GDP_deflator
gen real_return=d.real_close/l.real_close*100

* calculate growth-sensitivity of each sector
foreach sector in agriculture textiles metallurgy public_utilities insurance banking mining industrials shipping {
	dis as text "`sector'"
	corr real_return RGDP_growth if index=="`sector'"
	reg real_return RGDP_growth if index=="`sector'"

	scalar sensitivity_`sector'=_b[RGDP_growth]

	}
scalar list
mat sensitivity=(sensitivity_agriculture \ sensitivity_textiles \ sensitivity_metallurgy \ sensitivity_public_utilities \ sensitivity_insurance \ sensitivity_banking \ sensitivity_mining \ sensitivity_industrials \ sensitivity_shipping)
clear
svmat sensitivity
gen sector="Agriculture and Fishing" if _n==1
replace sector="Textile" if _n==2
replace sector="Metallurgy" if _n==3
replace sector="Public utilities" if _n==4
replace sector="Insurance" if _n==5
replace sector="Banks and Finance" if _n==6
replace sector="Mining" if _n==7
replace sector="Industrials" if _n==8
replace sector="Shipping" if _n==9
save "growth_sensitivities.dta", replace

* Generate Table 6
encode sector, gen(sector_id)
order sector sensitivity
sort sensitivity
mkmat sector_id sensitivity, matrix(growth_sens)
matrix rownames growth_sens = "Shipping" "Textiles" "Mining" "Banks and Finance" "Insurance" "Industrials" "Metallurgy" "Utilities" "Agriculture and Fishing"
mat list growth_sens
esttab matrix(growth_sens) using Table6.tex, booktabs replace
