version 15.1
clear*

* set working directory
cd "/Users/dan/Google Drive/Chile_Paper/JDE REVISION/THIRD JDE SUBMISSION/REPLICATION FILES (Apr 2018)"

* import 1977 input-output Table for the Chilean economy
import excel "1977_IOT_Table/Chile_1977_IOT.xlsx", sheet("MIP1977") cellrange(B6:AF27) firstrow clear

* install IOT package if not already installed
*ssc install iot
destring, replace

* sector names
rename B agriculture
rename C fishery
rename D mining
rename E food_drink_tobacco
rename F textiles
rename G paper_and_printing
rename H chemical
rename I manuf_and_metal
rename J equipment
rename K utilities
rename L construction
rename M commerce
rename N transports_comm
rename O financial_serv
rename P housing_serv
rename Q education
rename R health_services
rename S hotels_restaurants
rename T public_administration
rename U imputed_bserv
rename V imputed_cserv
rename AD final_demand
rename Utilizaciontotal gross_output
foreach vars of varlist _all {
	replace `vars'=0 if `vars'==.
	}
gen n = _n
replace final_demand=0.00000000000000000000000000000001 if (n==20 | n==21) & final_demand==0
replace gross_output=0.00000000000000000000000000000001 if (n==20 | n==21) & gross_output==0

* declare as IOT and store Leontief inverse matrix
iot agriculture fishery mining food_drink_tobacco textiles paper_and_printing chemical manuf_and_metal equipment utilities construction commerce transports_comm financial_serv housing_serv education health_services hotels_restaurants public_administration imputed_bserv imputed_cserv, fd(final_demand) invt(1)
matrix leontief_inverse=e(invia)

* import labor compensation vector
preserve
import excel "1977_IOT_Table/Chile_1977_IOT.xlsx", sheet("CALCULATIONS") cellrange(Z1:Z22) firstrow clear
rename totallabor lcompensation
gen n=_n
tempfile lcompensation
save `lcompensation'
restore

merge 1:1 n using `lcompensation'

*gen direct labor costs coefficients
gen lcoeff=lcompensation/gross_output
mkmat lcoeff
matrix t_lcoeff=lcoeff'

* gen overall (direct + indirect) labor costs per unit of output
matrix labor_requirements = t_lcoeff * leontief_inverse
matrix l_intensity = labor_requirements'
matrix list l_intensity
matrix rownames l_intensity = overall_wage_costs 
matrix wage_costs = (l_intensity, lcoeff)
mat list wage_costs

clear
svmat wage_costs
rename wage_costs1 overall_wage_costs
rename wage_costs2 direct_wage_costs
gen sector="agriculture" if _n==1
replace sector="fishery" if _n==2
replace sector="mining" if _n==3
replace sector="food_drink_tobacco" if _n==4
replace sector="textiles" if _n==5
replace sector="paper_and_printing" if _n==6
replace sector="chemical" if _n==7
replace sector="manuf_and_metal" if _n==8
replace sector="equipment" if _n==9
replace sector="utilities" if _n==10
replace sector="construction" if _n==11
replace sector="commerce" if _n==12
replace sector="transport_and_communications" if _n==13
replace sector="banks & finance" if _n==14
replace sector="imputed housing services" if _n==15
replace sector="education" if _n==16
replace sector="health_services" if _n==17
replace sector="hotels_restaurants" if _n==18
replace sector="public_administration_and_defense" if _n==19
list
drop if sector=="" | sector=="imputed housing services" | sector=="public_administration_and_defense"
sort overall_wage_costs
list
rename sector sector_iot
save labor_costs.dta, replace

* generate Table 7
encode sector_iot, gen(sector_id)
order sector_id overall direct
sort overall
mkmat sector_id overall direct, matrix(labor_costs)
matrix rownames labor_costs = "Chemicals" "Agriculture" "Commerce" "Food Drink and Tobacco" "Textiles" "Utilities" "Paper and Printing" "Fishery" "Equipment" "Mining" "Basic manuf and metallurgy" "Transport and Communications" "Banks and Finance" "Construction" "Hotels and Restaurants" "Health Services" "Education"
mat list labor_costs
esttab matrix(labor_costs) using Table7.tex, booktabs replace
