version 15.1
clear*

* set working directory
cd "/Users/dan/Google Drive/Chile_Paper/JDE REVISION/THIRD JDE SUBMISSION/REPLICATION FILES (Apr 2018)"

* install 'winsor' package if not already installed
*ssc install winsor

* estimate growth sensitivity of sectoral stock market indexes (note: this includes proprietary data on sectoral stock market indexes for the Santiago stock market exchange, that can be obtained from Global Financial Data.)
do "Table 6 (growth_sensitivity_estimation).do"
tempfile growth_sensitivities
save `growth_sensitivities'

* calculate overall labor costs by sector based on the 1977 Input-Output Tables for the Chilean economy
do "Table 7 (labor_costs_calculation).do"
tempfile labor_costs
save `labor_costs'

* create firm-level dataset
do create_firm_level_dataset.do
keep if (Allende_sep_change!=. | coup_sep_change!=. | Allende_day_change!=. | coup_day_change!=.)

* create sector division that allows best possible matching with the stock market sectoral indexes provided by Global Financial Data
replace CATEGORIA="CONSTRUCCIONES" if (CATEGORIA=="INMOB, CONST Y HOTELES") & (sl_sector!="Real Estate" & substr(EMPRESAS, 1, 12)!="INMOBILIARIA" & substr(EMPRESAS, 1, 6)!="INVERS" & substr(EMPRESAS, 1, 4) != "INV." & substr(EMPRESAS, 1, 5)!="RENTA")
replace CATEGORIA="INMOBILIARIA" if (CATEGORIA=="INMOB, CONST Y HOTELES") & (sl_sector=="Real Estate" | substr(EMPRESAS, 1, 12)=="INMOBILIARIA" | substr(EMPRESAS, 1, 6) == "INVERS" | substr(EMPRESAS, 1, 4) == "INV." | substr(EMPRESAS, 1, 5) == "RENTA")

gen sector=""
replace sector="Agriculture and Fishing" if (EM_sector=="agriculture" | CATEGORIA=="AGROPECUARIAS" | CATEGORIA=="PESQUERAS"| sl_sector=="Forestry")
replace sector="Textile"                 if (EM_sector=="textile" | CATEGORIA=="TEXTILES")
replace sector="Metallurgy"              if (EM_sector=="metallurgy" | CATEGORIA=="METALURGICAS")
replace sector="Mining"                  if (EM_sector=="mining" | CATEGORIA=="MINERAS")
replace sector="Public utilities"        if (CATEGORIA=="UTLIDAD PUBLICA")
replace sector="Insurance"               if (EM_sector=="insurance" | CATEGORIA=="CIA DE SEGUROS")
replace sector="Banks and Finance"       if (EM_sector=="banking" | CATEGORIA=="BANCARIAS" | sl_sector=="Real Estate" | CATEGORIA=="INMOBILIARIA") & sector==""
replace sector="Shipping"                if (CATEGORIA=="MARITIMAS") & sector==""
replace sector="Industrials"             if (CATEGORIA=="MANUFACTURA" | CATEGORIA=="ALIM, BEB Y LICORES" | firm=="Molinera Coronel" | CATEGORIA=="IMPRENTA Y LITOGRAFIA" | CATEGORIA=="CONSTRUCCIONES" | (sl_sector=="INDUSTRIAS MANUFACTURERAS" & CATEGORIA=="" & EM_sector=="manufacturing_and_others") | firm=="Indugas")  


* create sector division that allows best possible matching with the sectoral classification of the Chilean 1977 Input-Ouput Tables
replace CATEGORIA="CONSTRUCCIONES" if (CATEGORIA=="INMOB, CONST Y HOTELES") & (sl_sector!="Real Estate" & substr(EMPRESAS, 1, 12)!="INMOBILIARIA" & substr(EMPRESAS, 1, 6)!="INVERS" & substr(EMPRESAS, 1, 4) != "INV." & substr(EMPRESAS, 1, 5)!="RENTA")
replace CATEGORIA="INMOBILIARIA" if (CATEGORIA=="INMOB, CONST Y HOTELES") & (sl_sector=="Real Estate" | substr(EMPRESAS, 1, 12)=="INMOBILIARIA" | substr(EMPRESAS, 1, 6) == "INVERS" | substr(EMPRESAS, 1, 4) == "INV." | substr(EMPRESAS, 1, 5) == "RENTA")

gen sector_iot=""
replace sector_iot="agriculture" if (CATEGORIA=="AGROPECUARIAS"|sl_sector=="Forestry"|EM_sector=="agriculture")
replace sector_iot="fishery" if CATEGORIA=="PESQUERAS"
replace sector_iot="mining" if (EM_sector=="mining" | CATEGORIA=="MINERAS")
replace sector_iot="textiles" if (EM_sector=="textile" | CATEGORIA=="TEXTILES")
replace sector_iot="utilities" if (CATEGORIA=="UTLIDAD PUBLICA")
replace sector_iot="banks & finance" if (EM_sector=="banking" | CATEGORIA=="BANCARIAS" | sl_sector=="Real Estate" | CATEGORIA=="INMOBILIARIA" | EM_sector=="insurance" | CATEGORIA=="CIA DE SEGUROS") & sector_iot==""
replace sector_iot="construction" if CATEGORIA=="CONSTRUCCIONES"
replace sector_iot="food_drink_tobacco" if (CATEGORIA=="ALIM, BEB Y LICORES"| substr(firm, 1, 8)=="Molinera" | sl_sector=="Tabacco Manufacturing")
replace sector_iot="paper_and_printing" if ( substr(firm, 1, 5)=="Papel" | CATEGORIA=="IMPRENTA Y LITOGRAFIA" )
replace sector_iot="commerce" if (CATEGORIA=="COMERC, DIST Y FERIAS")
replace sector_iot="transport_and_communications" if (CATEGORIA=="MARITIMAS"|sl_sector=="TRANSPORTE Y ALMACENAMIENTO")
replace sector_iot="manuf_and_metal" if (EM_sector=="metallurgy" | CATEGORIA=="METALURGICAS"| CATEGORIA=="MANUFACTURA" | sl_sector=="INDUSTRIAS MANUFACTURERAS" | firm=="Indugas") & sector_iot==""
*replace sector_iot="hotels_restaurants" if (CATEGORIA=="DEPORTES, ESPARC E HIPICA")
replace sector_iot="chemical" if firm=="Farmo Quimica"

* merge with estimated growth sensitivities
merge m:1 sector using `growth_sensitivities', gen(_merge_gs)
* merge with estimated wage content
merge m:1 sector_iot using `labor_costs', gen(_merge_lc)

winsor coup_sep_change, h(1) gen(Wcoup_sep_change)

* Table 8 - firm-level regressions investigating potential mechanisms
egen A_change = std(Allende_sep_change)
egen wc_change = std(Wcoup_sep_change)
egen c_change = std(coup_sep_change)

egen labor_costs=std(overall_wage_costs)
egen growth_sensitivity=std(sensitivity)

reg A_change growth_sensitivity, cluster(sector)
outreg2 using "mechanisms_analysis", replace nocons dec(2) tex
reg A_change labor_costs, cluster(sector_iot)
outreg2 using "mechanisms_analysis", append nocons dec(2) tex
reg A_change growth_sensitivity labor_costs, cluster(sector_iot)
outreg2 using "mechanisms_analysis", append nocons dec(2) tex

reg c_change growth_sensitivity, cluster(sector)
outreg2 using "mechanisms_analysis", append nocons dec(2) tex
reg c_change labor_costs, cluster(sector_iot)
outreg2 using "mechanisms_analysis", append nocons dec(2) tex
reg c_change growth_sensitivity labor_costs, cluster(sector_iot)
outreg2 using "mechanisms_analysis", append nocons dec(2) tex

reg wc_change growth_sensitivity, cluster(sector)
outreg2 using "mechanisms_analysis", append nocons dec(2) tex
reg wc_change labor_costs, cluster(sector_iot)
outreg2 using "mechanisms_analysis", append nocons dec(2) tex
reg wc_change growth_sensitivity labor_costs, cluster(sector_iot)
outreg2 using "mechanisms_analysis", append nocons dec(2) tex

* GRAPHS
label variable sensitivity1 "Estimated growh-sensitivity"
label variable overall_wage_costs "Direct and indirect labor costs per unit of output"
label variable direct_wage_costs "Direct labor costs per unit of output"

twoway (scatter Allende_sep_change sensitivity1) (lfit Allende_sep_change sensitivity1, lpattern(solid) lcolor(blue) lwidth(medium)), yline(0, lstyle( color(cranberry))) scheme(plotplainblind) name(growth_Sep_1970) legend(ring(0) pos(12) region(lstyle(foreground) lwidth(small)) )
twoway (scatter coup_sep_change sensitivity1 if coup_sep_change<1000) (lfit coup_sep_change sensitivity1 if coup_sep_change<1000, yline(0, lstyle( color(cranberry))) lpattern(solid) lcolor(blue) lwidth(medium)), scheme(plotplainblind) name(growth_Sep_1973) legend(ring(0) pos(8) region(lstyle(foreground) lwidth(vsmall)))

twoway (scatter Allende_sep_change overall_wage_costs if overall_wage_costs!=. & Allende_sep_change!=.) (lfit Allende_sep_change overall_wage_costs if overall_wage_costs!=. & Allende_sep_change!=., lpattern(solid) lcolor(blue) lwidth(medium)), yline(0, lstyle( color(cranberry))) scheme(plotplainblind) name(wages_Sep_1970) legend(off ring(0) pos(11) region(lstyle(foreground) lwidth(small)) ) 
twoway (scatter coup_sep_change overall_wage_costs if coup_sep_change<1000 & overall_wage_costs!=.) (lfit coup_sep_change overall_wage_costs if coup_sep_change<1000 & overall_wage_costs!=., yline(0, lstyle( color(cranberry))) lpattern(solid) lcolor(blue) lwidth(medium)), scheme(plotplainblind) name(wages_Sep_1973) legend(off ring(0) pos(11) region(lstyle(foreground) lwidth(vsmall)))

