version 15.1
clear*
cd "/Users/dan/Google Drive/Chile_Paper/JDE REVISION/THIRD JDE SUBMISSION/REPLICATION FILES (Apr 2018)/daily_aggregate_data"

* import SP500
import delimited "sp_500.csv", clear varnames(1)
destring close, replace force
rename date s_date
gen date=date(s_date, "YMD")
format date %td
rename close sp500
keep date sp500
tempfile sp500
save `sp500'

* import argentina index (IBN)
import excel "GFD_ARG_IBGD.xlsx", sheet("Price Data") firstrow clear
rename Date Date_Original
gen Date2 = subinstr(Date, "/", "-", .)
gen date = date(Date2, "MDY")
format date %td
drop if date==.
rename Close ibn
keep date ibn
tempfile arg
save `arg'

* Import IGPA index (proprietary data: must be purchased from the Santiago Stock Exchange)
clear*
import excel "daily_IPSA_IGPA_historical.xlsx", sheet("Hoja1") firstrow clear
keep FECHA IGPA IPSA
list FECHA IPSA IGPA if IPSA==0|IGPA==0
* correct some mistakes
replace IPSA=. if IPSA==0
replace IPSA=. if FECHA=="2016-12-23"|FECHA=="2014-12-24"
replace IGPA=. if FECHA=="2016-12-23"|FECHA=="2014-12-24"
replace IGPA=.000222735 if FECHA=="1963-02-18"
replace IGPA=IGPA*1000 if FECHA=="1970-04-09"

gen date= daily(FECHA,"YMD")
gen date_1 = date
format date %td
tsset date

merge 1:1 date using `sp500', gen(_merge_sp500)
merge 1:1 date using `arg', gen(_merge_arg)

gen year=year(date)
gen month=month(date)
gen day_num=day(date)

tsset date

drop _merge*



* GEN RATES OF CHANGE
drop if IGPA==.
sort date
gen n=_n
tsset n

replace sp500=l.sp500 if sp500==.
replace ibn=l.ibn if ibn==.

gen sp500_change=d.sp500/l.sp500*100
gen igpa_change=d.IGPA/l.IGPA*100
gen ibn_change=d.ibn/l.ibn*100

* GEN VARIABLES INDICATING DISTANCE IN TRADING DAYS TO ALLENDE ELECTION AND TO 1973 COUP
gen allende_election=0
replace allende_election=1 if date==td(08sep1970) 
sum n if allende_election==1
scalar n_allende=r(mean)
gen tdays_to_allende_election=n-n_allende+1
replace tdays_to_allende_election=tdays_to_allende_election-1 if tdays_to_allende<1

gen coup=0
replace coup=1 if date==td(17sep1973)
sum n if date==td(17sep1973)
scalar after_coup_tday = r(mean)
gen tdays_to_coup=n-after_coup_tday+1
replace tdays_to_coup=tdays_to_coup-1 if tdays_to_coup<1

keep date IGPA sp500 ibn year month n sp500_change igpa_change ibn_change allende_election coup tdays_to_allende_election tdays_to_coup
label variable date "Calendar Date"
label variable n "Number of trading days in Santiago relative to 2 Jan 1961"
label variable sp500_change "Daily Return on SP500 Index"
label variable igpa_change "Daily Return on IGPA Index"
label variable allende_election "Indicator for first trading day after Allende election"
label variable coup "Indicator for first trading day after 1973 coup"
label variable tdays_to_allende_election "Number of trading days relative to Allende election"
label variable tdays_to_coup "Number of trading days relative to 1973 Coup"
label variable ibn_change "Daily return on IBN index (Argentina)"
label variable ibn "IBN stock market Index (Argentina)"
